<?
function fechachr($fecha) {
   $fecha = getdate(time());
   $adia = array("Lunes","Martes","Miercoles","Jueves","Viernes","Sabado","Domingo");
   $cdia = $adia[$fecha["wday"]-1];
   $ndia = $fecha["mday"];
   $ames = array("Enero","Febrero","Marzo","Abril","Mayo","Junio","Julio","Agosto","Setiembre","Octubre","Noviembre","Diciembre");
   $cmes = $ames[$fecha["mon"]-1];
   $anio = $fecha["year"];
   $cfecha = "$cdia, $ndia de $cmes del $anio";
   return $cfecha;
}

function fechahoydinamica($fecha1) {
   $fecha = getdate($fecha1);
   $adia = array("Lunes","Martes","Miercoles","Jueves","Viernes","Sabado","Domingo");
   $cdia = $adia[$fecha["wday"]-1];
   $ndia = $fecha["mday"];
   $ames = array("Enero","Febrero","Marzo","Abril","Mayo","Junio","Julio","Agosto","Setiembre","Octubre","Noviembre","Diciembre");
   $cmes = $ames[$fecha["mon"]-1];
   $anio = $fecha["year"];
   $cfecha = "$cdia, $ndia de $cmes del $anio";
   return $cfecha;
} 
function fechahoydinamica1($fecha1) {
   $diaa=substr($fecha1,0,2);
   $mess=substr($fecha1,3,2);
   $anio=substr($fecha1,6,4);
   $fecha = getdate($fecha1);
   $adia = array("Lunes","Martes","Miercoles","Jueves","Viernes","Sabado","Domingo");
   $cdia = $adia[$fecha["wday"]-1];
   $ndia = $fecha["mday"];
   $ames = array("01"=>"ENERO","02"=>"FEBRERO","03"=>"MARZO","04"=>"ABRIL","05"=>"MAYO","06"=>"JUNIO","07"=>"JULIO","08"=>"AGOSTO","09"=>"SETIEMBRE","10"=>"OCTUBRE","11"=>"NOVIEMBRE","12"=>"DICIEMBRE");
   $cmes = $ames[$mess];   
   $cfecha = "$cdia, $diaa de $cmes del $anio";
   return $cfecha;
} 
 function meshoy($mes) {      
   $ames = array("01"=>"ENERO","02"=>"FEBRERO","03"=>"MARZO","04"=>"ABRIL","05"=>"MAYO","06"=>"JUNIO","07"=>"JULIO","08"=>"AGOSTO","09"=>"SETIEMBRE","10"=>"OCTUBRE","11"=>"NOVIEMBRE","12"=>"DICIEMBRE");
   $cmes = $ames[$mes];      
   return $cmes;
} 
function getNumCeros($nNum)
  {
    $Num="00000".$nNum;
    $PosiIni=(strlen($Num)-5);
    return substr($Num,$PosiIni,5);
}
function getNumCero($nNum)
  {
    $Num="000000".$nNum;
    $PosiIni=(strlen($Num)-6);
    return substr($Num,$PosiIni,6);
  }  
  function extraerfechamysql($f)
  {
    $fech=substr($f,6,4)."-".substr($f,3,2)."-".substr($f,0,2);
	return $fech;
  }
  function extraerfechanormal($f)
  {
    $fech=substr($f,8,2)."-".substr($f,5,2)."-".substr($f,0,4);
	return $fech;
  } 
  function extraerDiaiFN($f)
  {
    $fech=substr($f,8,2);
	return $fech;
  } 
  function extraerMesiFN($f)
  {
    $fech=substr($f,5,2);
	return $fech;
  }
  function extraerAnioiFN($f)
  {
    $fech=substr($f,0,4);
	return $fech;
  }
  function extraerDiafFN($f)
  {
    $fech=substr($f,8,2);
	return $fech;
  } 
  function extraerMesfFN($f)
  {
    $fech=substr($f,5,2);
	return $fech;
  }
  function extraerAniofFN($f)
  {
    $fech=substr($f,0,4);
	return $fech;
  }  
  function extraermes($f)
  {
    $fech=substr($f,3,2);
	return $fech;
  }
  function extraeranio($f)
  {
    $fech=substr($f,6,4);
	return $fech;
  }
  function extracodper($c)
  {
    $codigo=substr($c,1,2);
	return $fech;
  }    
  function restaF($mesi,$diai,$anioi,$mesf,$diaf,$aniof){
	$date1 = mktime(0,0,0,$mesi,$diai,$anioi);
	$date2 = mktime(0,0,0,$mesf,$diaf,$aniof);
	$total_days = 0;
	while($date1 < $date2) { 
	$total_days++; 
	$date1 += 86400; 
	}
	return $total_days+1;
  }
  function calcular_tiempo_trasnc($hora1,$hora2){ 
    $separar[1]=explode(':',$hora1); 
    $separar[2]=explode(':',$hora2); 
	$total_minutos_trasncurridos[1] = ($separar[1][0]*60)+$separar[1][1]; 
	$total_minutos_trasncurridos[2] = ($separar[2][0]*60)+$separar[2][1]; 
	return $total_minutos_trasncurridos = ($total_minutos_trasncurridos[1]-$total_minutos_trasncurridos[2])/60; 
  }
  function calcular_tiempo_trasnc1($hora1,$hora2){ 
    $separar[1]=explode(':',$hora1); 
    $separar[2]=explode(':',$hora2); 
	$total_minutos_trasncurridos[1] = ($separar[1][0]*60)+$separar[1][1]; 
	$total_minutos_trasncurridos[2] = ($separar[2][0]*60)+$separar[2][1]; 
	return $total_minutos_trasncurridos = ($total_minutos_trasncurridos[1]-$total_minutos_trasncurridos[2])/60; 
  }  
  function calcular_horas_formato($hora1,$hora2){
  $divisor=60;
  $minutos=60;
  $separar[1]=explode(':',$hora1); 
  $separar[2]=explode(':',$hora2);  
  $tminutos=$minutos-$separar[1][1];  
  $total_minutos[1] = $tminutos+$separar[2][1];  
  $cociente=floor($total_minutos[1] / $divisor);
  $resto = $total_minutos[1] % $divisor;
  return $suma_horas=$cociente.":".$resto;
  }
  function calcular_horas_formato_inversai($hora){
  $divisor=60;
  $minutos=60;
   
  $tminutos=round($minutos*$hora);    
  $cociente=floor($tminutos / $divisor);
  
  $resto = $tminutos % $divisor;
  if($resto<10){
  return $suma_horas=$cociente.":0".$resto;
  }else{
  return $suma_horas=$cociente.":".$resto;
  }
  }
  function calcular_horas_formato_inversa($hora){
  $divisor=60;
  $minutos=60;
   
  $tminutos=$minutos*$hora."<br>";    
  $cociente=floor($tminutos / $divisor);
  
  $resto = $tminutos % $divisor;
  if($resto<10){
  return $suma_horas=$cociente.":0".$resto;
  }else{
  return $suma_horas=$cociente.":".$resto;
  }
  }
  function calcular_horas_formato_inversa1($hora){
  $divisor=60;
  $minutos=60;
   
  $tminutos=$minutos*$hora."<br>";    
  $cociente=floor($tminutos/$divisor);
  
  $resto=$tminutos%$divisor;
  if($resto<10){
  return $suma_horas=$cociente.":0".$resto;
  }else{
  return $suma_horas=$cociente.":".$resto;
  }
  }
  function nimutotohora($hora,$minuto){
  $mincal=$minuto%60;  
  $horacal=$hora+floor($minuto/60);
  	if($mincal<10){
  	return $horacal.":0".$mincal;
	}else{
	return $horacal.":".$mincal;
	}
  }
	function sumahoras ($hora1,$hora2){
	$hora1=explode(":",$hora1);
	$hora2=explode(":",$hora2);
	$horas=(int)$hora1[0]+(int)$hora2[0];
	$minutos=(int)$hora1[1]+(int)$hora2[1];	
	$segundos=(int)$hora1[2]+(int)$hora2[2];
	$horas+=(int)($minutos/60);
	$minutos=(int)($minutos%60)+(int)($segundos/60);	
	$segundos=(int)($segundos%60);
	return (intval($horas)<10?'0'.intval($horas):intval($horas)).':'.($minutos<10?'0'.$minutos:$minutos).':'.($segundos<10?'0'.$segundos:$segundos);
	} 
	
function dif($h1,$h2){
$h=((strtotime($h1)-strtotime($h2)))/3600;
$m=intval((($h)-intval($h))*60);
$s=intval((((($h)-intval($h))*60)-$m)*60);
return (intval($h)<10?'0'.intval($h):intval($h)).':'.($m<10?'0'.$m:$m);
}
 function RestarHoras($horaini,$horafin)
{
    $horai=substr($horaini,0,2);
    $mini=substr($horaini,3,2);
    //$segi=substr($horaini,6,2);
 
    $horaf=substr($horafin,0,2);
    $minf=substr($horafin,3,2);
    //$segf=substr($horafin,6,2);
 
    $ini=((($horai*60)*60)+($mini*60)/*+$segi*/);
    $fin=((($horaf*60)*60)+($minf*60)/*+$segf*/);
 
    $dif=$fin-$ini;
 
    $difh=floor($dif/3600);
    $difm=floor(($dif-($difh*3600))/60);
    //$difs=$dif-($difm*60)-($difh*3600);
    return date("H:i",mktime($difh,$difm));
    //return date("H-i-s",mktime($difh,$difm,$difs));
}
function convertirhhmmtohoras($hora){
$hora = strtotime($hora);
return $thpv = date('H', $hora) + date('i', $hora) / 60;
}
?>
