<?php
  include("stilos/config.inc.php");
  include("../clases/BDConexion.php");
  include("../clases/clsPer.php");
  include("funcion/funciones.php");
  include("Funciones.php");
  session_start();
  $objPer=new clsPer;
  
?>
<!DOCTYPE HTML PUBLIC "-//W3C//DTD HTML 4.01 Transitional//EN" "http://www.w3.org/TR/html4/loose.dtd">
<html>
<head>
<title><MMString:LoadString id="insertbar/formsHidden" /></title>
<meta http-equiv="Content-Type" content="text/html; charset=iso-8859-1">
<link href="style.css" rel="stylesheet" type="text/css">

<link href="Estilos.css" rel="stylesheet" type="text/css">

<link href="stilos/Estilos.css" rel="stylesheet" type="text/css">

<!-- Copyright 2000,2001 Macromedia, Inc. All rights reserved. -->
<? $url="cvp_ubicacion_per.php?dociden_per=$dociden_per&mes=$mes1&anio=$anio&tipo=$tipo&des=$des&fecha=$fecha"?>
<script>
function volver(form)
{
location.reload('<? echo $url ?>');
}
</script>
<script language="JavaScript"> 
<!--
function print_1(sURL,x,y) {
if (!window.focus) return;
			var par;
			par = "width=" +x + ",height="+y+","
			par = par + "dependent=no,scrollbars=yes,resizable=yes,"
			par = par + "menubar=no,toolbar=no,status=no"
			var ventana = window.open(sURL,"printer",par)
			ventana.focus();
}
//--> 
</script>

</head>

<body background="../imagenes/fondo.jpg">
<table width="820" border="0" align="center" cellpadding="0" cellspacing="0" >
  <tr valign="top" >
    <td height="25" colspan="4">
    <div align="left" ></div></td>
  </tr>
  <tr class="lblCampo" >
    <td colspan="4"><div align="center">
        <table width="735" border="0" cellspacing="0" cellpadding="0">
          <tr>
            <td width="25"><img src="../estilo_tabla/parte_sup_izq.gif" width="25" height="25"></td>
            <td width="680" background="../estilo_tabla/parte_sup_cen.gif" valign="bottom">
			<div align="left" class="lblTitulo" >Seguimiento de la Ubicacion del Personal </div>			</td>
            <td width="25"><img src="../estilo_tabla/parte_sup_der.gif" width="25" height="25" border="0" usemap="#Map"></td>
          </tr>
          <tr>
            <td width="25" background="../estilo_tabla/parte_med_izq.gif">&nbsp;</td>
            <td width="680" height="86" background="../estilo_tabla/parte_med_cen.gif"><div align="center">
              <table width="679" border="0" cellspacing="0" cellpadding="0">
                <tr>
                  <td height="15"><div align="left"><? echo $appat_per." ".$apmat_per.", ".$nom_per;?></div></td>
                </tr>
                <tr>
				
                </tr>
                <tr>
                  <td><div align="center">
                    <table width="670" border="1" cellpadding="0" cellspacing="0" style="<?=$stylo['tabla']?>" bgcolor="<?=$c_fondo['fondo tabla']?>" bordercolor="<?=$bordetabla?>">
                      <tr valign="top" class="lblCampoBlanco" bgcolor="<?=$c_fondo_tr["fondo tr"]?>">
                        <td width="60"><div align="center">Matricula</div></td>
                        <td width="154"><div align="left">Tipo Transporte </div></td>
                        <td width="82"><div align="center">Dias Permanencia </div></td>
                        <td width="92"><div align="center">Fecha Salida </div></td>
                        <td width="88"><div align="center">Fecha Llegada </div></td>
                        <td width="93">
						  <div align="center">From</div></td>
                        <td width="85"><div align="center">Destino</div>                          <div align="center">
						  
						  </div></td>
                        </tr>
                      <? 											
					$resultado=$objPer->getUbicacionPer($dociden_per,$mes1,$anio);				
				   
                  while($filas=$objPer->NextRow($resultado))
                   {
				   $fi=$filas['testimado_ruta'];
				   $ffi=$filas['permanencia'];
    			   $codmpass=$filas['codigo_mpass'];  
				   $resultadof=$objPer->getNdias($fi,$codmpass);
				   $filasf=$objPer->NextRow($resultadof);
				   ?>
                      <tr valign="top" class="lblForm" >
                        <td class="lblForm">
                          <div align="center">
						  <? echo $filas['mat_trans']; ?>  
						  </div>
						</td>
                        <td class="lblForm"><div align="left"><?php echo strtoupper($filas['tipo_trans']); ?> </div></td>
                        <td class="lblForm"><div align="center">
						<?php
						//echo $filas['horallega_ruta'];
						if($filas['testimado_ruta']<=date("Y-m-d")){						
							/*$fi=$filas['testimado_ruta'];
							$ffi=$filas['permanencia']; 
							if($ffi==NULL){
								$ff="0000000000";
								echo "0";
							}else{
								$ff=$ffi;
								echo $dias_permanencia=restaF(extraerMesiFN($fi),extraerDiaiFN($fi),extraerAnioiFN($fi),extraerMesfFN($ff),extraerDiafFN($ff),extraerAniofFN($ff));
							    $tdias=$tdias+$dias_permanencia;
							}*/			
						if($ffi==NULL){								
								echo $filasf['fechas'];
							}else{
								$ff=$ffi;
								echo $dias_permanencia=restaF(extraerMesiFN($fi),extraerDiaiFN($fi),extraerAnioiFN($fi),extraerMesfFN($ff),extraerDiafFN($ff),extraerAniofFN($ff));
							$tdias=$tdias+$dias_permanencia;
							}				
						}else{
						echo "No LLega Al destino";
						}
						?>
						</div></td>
                        <td class="lblForm"><div align="center"><?php echo extraerfechanormal($filas['fecha_ruta']); ?></div></td>
                        <td class="lblForm"><div align="center"><?php echo extraerfechanormal($filas['testimado_ruta']); ?></div></td>
                        <td class="lblForm">						
						  <div align="center"><?php echo strtoupper($filas['origen']); ?>
                          </div>						 </td>
                        <td class="lblForm"><div align="center"></div>
						  <div align="center"><?php echo strtoupper($filas['destino']); ?>
						    
						  </div></td>
                        </tr>
                      
                      <? 
			}
			$objPer->Liberar($resultado);  
			?>  
				<tr valign="top" class="lblForm" >
                        <td colspan="2" class="lblForm"><div align="right">Total dias de Permanencia </div></td>
                        <td class="lblForm"><div align="center"><? echo $tdias?></div></td>
                        <td class="lblForm">&nbsp;</td>
                        <td class="lblForm">&nbsp;</td>
                        <td class="lblForm">&nbsp;</td>
                        <td class="lblForm">&nbsp;</td>
                      </tr>
                    </table>
			 </div>
			 </td>
                </tr>
				
                <tr>
                  <td><div align="left"></div></td>
                </tr>
                <tr>
                  <td><div align="center">
				  </div></td>
                </tr>
				 
                 <tr>
				 <form name="form1" method="post" action="cvp_ubicacion_per_print.php">
                   <td><div align="center">
                     <table width="450" border="0" cellspacing="0" cellpadding="0">
                       <tr>
                         <td width="104"><div align="right">
                           <input type="button" name="Submit" value=".:Imprimir:." style="<?=$stylo['st2']?>" class="botira" onClick="javascript:print_1('cvp_ubicacion_per_print.php?mes1=<? echo $mes1?>&anio=<? echo $anio?>&dociden_per=<? echo $dociden_per?>&personal=<? echo $appat_per." ".$apmat_per.", ".$nom_per;?>',800,600)">                           
                         </div></td>
                         <td width="93"><input name="dociden_per" type="hidden" id="dociden_per" value="<? echo $dociden_per?>">
                           <input name="mes1" type="hidden" id="mes1" value="<? echo $mes1?>">
                           <input name="anio" type="hidden" id="anio" value="<? echo $anio?>">
                           <input name="personal" type="hidden" id="personal" value="<? echo $appat_per." ".$apmat_per.", ".$nom_per;?>"></td>
                         <td width="104"><div align="left">
                           <input type="button" name="Submit2" value=".:Regresar:." style="<?=$stylo['st2']?>" class="botira" onClick="volver(this.form);">
                         </div></td>
                       </tr>
                     </table>
                   </div></td>
				    </form>
                 </tr>
                 
              </table>
            </div></td>
            <td background="../estilo_tabla/parte_med_der.gif">&nbsp;</td>
          </tr>
          <tr>
            <td><img src="../estilo_tabla/parte_inf_izq.gif" width="25" height="20"></td>
            <td background="../estilo_tabla/parte_inf_cen.gif">&nbsp;</td>
            <td><img src="../estilo_tabla/parte_inf_der.gif" width="25" height="20"></td>
          </tr>
        </table>
    </div></td>
  </tr>
  <tr valign="top" class="lblCampo" >
    <td colspan="4">
      <div align="center"> </div></td>
  </tr>
</table>

<map name="Map">
  <area shape="rect" coords="2,5,22,21" href="fondo.php">
</map>
</body>

</html>

